<?php

namespace Asadi\Mendor\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Mendor\Interfaces\MendorRepositoryInterface;
use Asadi\Mendor\Repositories\Presenter\MendorItemTransformer;

/**
 * Pubic API controller class.
 */
class MendorPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Mendor\Interfaces\MendorRepositoryInterface $mendor
     *
     * @return type
     */
    public function __construct(MendorRepositoryInterface $mendor)
    {
        $this->repository = $mendor;
        parent::__construct();
    }

    /**
     * Show mendor's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $mendors = $this->repository
            ->setPresenter('\\Asadi\\Mendor\\Repositories\\Presenter\\MendorListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $mendors['code'] = 2000;
        return response()->json($mendors)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show mendor.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $mendor = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($mendor)) {
            $mendor         = $this->itemPresenter($module, new MendorItemTransformer);
            $mendor['code'] = 2001;
            return response()->json($mendor)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
