<?php

namespace Asadi\Mendor\Http\Controllers\Api;

use App\Http\Controllers\Api\UserController as BaseController;
use Asadi\Mendor\Http\Requests\MendorRequest;
use Asadi\Mendor\Interfaces\MendorRepositoryInterface;
use Asadi\Mendor\Models\Mendor;

/**
 * User API controller class.
 */
class MendorUserController extends BaseController
{
    /**
     * Initialize mendor controller.
     *
     * @param type MendorRepositoryInterface $mendor
     *
     * @return type
     */
    public function __construct(MendorRepositoryInterface $mendor)
    {
        $this->repository = $mendor;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Asadi\Mendor\Repositories\Criteria\MendorUserCriteria());
        parent::__construct();
    }

    /**
     * Display a list of mendor.
     *
     * @return json
     */
    public function index(MendorRequest $request)
    {
        $mendors  = $this->repository
            ->setPresenter('\\Asadi\\Mendor\\Repositories\\Presenter\\MendorListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $mendors['code'] = 2000;
        return response()->json($mendors) 
            ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display mendor.
     *
     * @param Request $request
     * @param Model   Mendor
     *
     * @return Json
     */
    public function show(MendorRequest $request, Mendor $mendor)
    {

        if ($mendor->exists) {
            $mendor         = $mendor->presenter();
            $mendor['code'] = 2001;
            return response()->json($mendor)
                ->setStatusCode(200, 'SHOW_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }

    /**
     * Show the form for creating a new mendor.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(MendorRequest $request, Mendor $mendor)
    {
        $mendor         = $mendor->presenter();
        $mendor['code'] = 2002;
        return response()->json($mendor)
            ->setStatusCode(200, 'CREATE_SUCCESS');
    }

    /**
     * Create new mendor.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(MendorRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $mendor          = $this->repository->create($attributes);
            $mendor          = $mendor->presenter();
            $mendor['code']  = 2004;

            return response()->json($mendor)
                ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message' => $e->getMessage(),
                'code'    => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }

    }

    /**
     * Show mendor for editing.
     *
     * @param Request $request
     * @param Model   $mendor
     *
     * @return json
     */
    public function edit(MendorRequest $request, Mendor $mendor)
    {
        if ($mendor->exists) {
            $mendor         = $mendor->presenter();
            $mendor['code'] = 2003;
            return response()-> json($mendor)
                ->setStatusCode(200, 'EDIT_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }
    }

    /**
     * Update the mendor.
     *
     * @param Request $request
     * @param Model   $mendor
     *
     * @return json
     */
    public function update(MendorRequest $request, Mendor $mendor)
    {
        try {

            $attributes = $request->all();

            $mendor->update($attributes);
            $mendor         = $mendor->presenter();
            $mendor['code'] = 2005;

            return response()->json($mendor)
                ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the mendor.
     *
     * @param Request $request
     * @param Model   $mendor
     *
     * @return json
     */
    public function destroy(MendorRequest $request, Mendor $mendor)
    {

        try {

            $t = $mendor->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('mendor::mendor.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
