<?php

namespace Asadi\Mendor\Http\Controllers;
use Litepie\Mendor\Http\Requests\MendorRequest;
use Litepie\Mendor\Models\Mendor;

trait MendorWorkflow {
	
    /**
     * Workflow controller function for mendor.
     *
     * @param Model   $mendor
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(MendorRequest $request, Mendor $mendor, $step)
    {

        try {

            $mendor->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('mendor::mendor.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/mendor/mendor/' . $mendor->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/mendor/mendor/' . $mendor->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for mendor.
     *
     * @param Model   $mendor
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Mendor $mendor, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $mendor->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('mendor::mendor.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('mendor::admin.mendor.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('mendor::admin.mendor.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('mendor::admin.mendor.message', $data)->render();

        }

    }
}