<?php

namespace Asadi\Mendor\Policies;

use App\User;
use Asadi\Mendor\Models\Mendor;

class MendorPolicy
{

    /**
     * Determine if the given user can view the mendor.
     *
     * @param User $user
     * @param Mendor $mendor
     *
     * @return bool
     */
    public function view(User $user, Mendor $mendor)
    {
        if ($user->canDo('mendor.mendor.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $mendor->user_id;
    }

    /**
     * Determine if the given user can create a mendor.
     *
     * @param User $user
     * @param Mendor $mendor
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('mendor.mendor.create');
    }

    /**
     * Determine if the given user can update the given mendor.
     *
     * @param User $user
     * @param Mendor $mendor
     *
     * @return bool
     */
    public function update(User $user, Mendor $mendor)
    {
        if ($user->canDo('mendor.mendor.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $mendor->user_id;
    }

    /**
     * Determine if the given user can delete the given mendor.
     *
     * @param User $user
     * @param Mendor $mendor
     *
     * @return bool
     */
    public function destroy(User $user, Mendor $mendor)
    {
        if ($user->canDo('mendor.mendor.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $mendor->user_id;
    }

    /**
     * Determine if the given user can verify the given mendor.
     *
     * @param User $user
     * @param Mendor $mendor
     *
     * @return bool
     */
    public function verify(User $user, Mendor $mendor)
    {
        if ($user->canDo('mendor.mendor.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('mendor.mendor.verify') 
        && $user->is('manager')
        && $mendor->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given mendor.
     *
     * @param User $user
     * @param Mendor $mendor
     *
     * @return bool
     */
    public function approve(User $user, Mendor $mendor)
    {
        if ($user->canDo('mendor.mendor.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
