<?php

namespace Asadi\Mendor\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Asadi\Mendor\Models\Mendor;

class MendorAction
{
    /**
     * Perform the complete action.
     *
     * @param Mendor $mendor
     *
     * @return Mendor
     */
    public function complete(Mendor $mendor)
    {
        try {
            $mendor->status = 'complete';
            return $mendor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Mendor $mendor
     *
     * @return Mendor
     */public function verify(Mendor $mendor)
    {
        try {
            $mendor->status = 'verify';
            return $mendor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Mendor $mendor
     *
     * @return Mendor
     */public function approve(Mendor $mendor)
    {
        try {
            $mendor->status = 'approve';
            return $mendor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Mendor $mendor
     *
     * @return Mendor
     */public function publish(Mendor $mendor)
    {
        try {
            $mendor->status = 'publish';
            return $mendor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Mendor $mendor
     *
     * @return Mendor
     */
    public function archive(Mendor $mendor)
    {
        try {
            $mendor->status = 'archive';
            return $mendor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Mendor $mendor
     *
     * @return Mendor
     */
    public function unpublish(Mendor $mendor)
    {
        try {
            $mendor->status = 'unpublish';
            return $mendor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
