<?php

namespace Asadi\Mendor\Workflow;

use Asadi\Mendor\Models\Mendor;
use Validator;

class MendorValidator
{

    /**
     * Determine if the given mendor is valid for complete status.
     *
     * @param Mendor $mendor
     *
     * @return bool / Validator
     */
    public function complete(Mendor $mendor)
    {
        return Validator::make($mendor->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given mendor is valid for verify status.
     *
     * @param Mendor $mendor
     *
     * @return bool / Validator
     */
    public function verify(Mendor $mendor)
    {
        return Validator::make($mendor->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given mendor is valid for approve status.
     *
     * @param Mendor $mendor
     *
     * @return bool / Validator
     */
    public function approve(Mendor $mendor)
    {
        return Validator::make($mendor->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given mendor is valid for publish status.
     *
     * @param Mendor $mendor
     *
     * @return bool / Validator
     */
    public function publish(Mendor $mendor)
    {
        return Validator::make($mendor->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given mendor is valid for archive status.
     *
     * @param Mendor $mendor
     *
     * @return bool / Validator
     */
    public function archive(Mendor $mendor)
    {
        return Validator::make($mendor->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given mendor is valid for unpublish status.
     *
     * @param Mendor $mendor
     *
     * @return bool / Validator
     */
    public function unpublish(Mendor $mendor)
    {
        return Validator::make($mendor->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
